@@ -3,7 +3,7 @@ import shutil
 
 PYTHONBREW_ROOT = '/tmp/pythonbrew.test'
 TESTPY_FILE = '/tmp/pythonbrew_test.py'
-TESTPY_VERSION = '2.6.6'
+TESTPY_VERSION = ['2.4.6', '2.5.5', '2.6.6']
 def cleanall():
     if os.path.isdir(PYTHONBREW_ROOT):
         shutil.rmtree(PYTHONBREW_ROOT)
@@ -13,9 +13,6 @@ def cleanall():
 def setup():
     os.environ['PYTHONBREW_ROOT'] = PYTHONBREW_ROOT
     cleanall()
-    fp = open(TESTPY_FILE, 'w')
-    fp.write("print 'test'")
-    fp.close()
     
 def teardown():
     cleanall()
